<?php 
/*
Plugin Name: Venus Assistant
Plugin URI:  https://seku.re/venus
Description: Build beautiful mobile friendly pages with premade Divi Page Layouts and UI Kits. Fully Integrated with the Divi Theme. The Venus Assistant adds all functions, scripts and CSS for optimal performance of the Venus UI Kit. Find tutorials, get support and troubleshoot directly from the plugin dashboard.

Version:     1.4.5
Author:      Divi Den
Author URI:  https://seku.re/divi-den
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Load Persist Admin notices Dismissal

if ( ! class_exists( 'PAnD' ) ) {
require_once( plugin_dir_path( __FILE__ ) . '/include/persist-admin-notices-dismissal.php' );
add_action( 'admin_init', array( 'PAnD', 'init' ) );
}

// Load the API Key library if it is not already loaded. Must be placed in the root plugin file.
if ( ! class_exists( 'venus_AM_License_Menu' ) ) {
    require_once( plugin_dir_path( __FILE__ ) . 'venus-am-license-menu.php' );
    venus_AM_License_Menu::instance( __FILE__, 'Venus Assistant', '1.4.5', 'plugin', 'https://divi-den.com/' );
}

//======================================================================
// CHECK IF DIVI THEME INSTALLED
//======================================================================

function venus_assistant_divi_not_installed_admin_notice__error() {
	$class = 'notice notice-error is-dismissible';
	$message = 'Action Required: The Divi Theme is not installed. You must install the Divi Theme for the Venus Assistant to work. If you do not already have it, <a href="https://seku.re/get-divi" target="_blank">Get it here</a>';

	printf( '<div data-dismissible="disable-venus-status-warning-notice-forever" class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), $message ); 
}

$divi_theme = wp_get_theme( 'Divi' );
if ( !($divi_theme->exists()) && PAnD::is_admin_notice_active( 'disable-venus-status-warning-notice-forever' ) ) add_action( 'admin_notices', 'venus_assistant_divi_not_installed_admin_notice__error' );


//======================================================================
// ADD ADMIN SCRIPTS
//======================================================================

add_action( 'admin_enqueue_scripts', 'venus_enqueue_admin_js' );

function venus_enqueue_admin_js( $hook_suffix ) {
    wp_enqueue_script( 'venus_assistant-clipboard', plugins_url('js/clipboard.min.js', __FILE__ ));
    wp_enqueue_script( 'venus_assistant-admin', plugins_url('js/venus-admin.js', __FILE__ ));
}

//======================================================================
// ADD ADMIN CSS
//======================================================================

add_action( 'admin_enqueue_scripts', 'venus_enqueue_admin_css' );

function venus_enqueue_admin_css() {
    wp_register_style( 'venus_assistant-admin-css', plugins_url('css/venus-admin.css', __FILE__ ));

 wp_enqueue_style( 'venus_assistant-admin-css' );
}

//======================================================================
// New options for plugin's setting
//======================================================================

function venus_add_options_on_activate() {

if (!get_option( 'venus_blog_modules')) add_option( 'venus_blog_modules', 'et_pb_on_state' );

if (!get_option( 'venus_blurbs_modules')) add_option( 'venus_blurbs_modules', 'et_pb_on_state' );

if (!get_option( 'venus_cta_modules')) add_option( 'venus_cta_modules', 'et_pb_on_state' );

if (!get_option( 'venus_form_modules')) add_option( 'venus_form_modules', 'et_pb_on_state' );

if (!get_option( 'venus_faq_modules')) add_option( 'venus_faq_modules', 'et_pb_on_state' );

if (!get_option( 'venus_features_modules')) add_option( 'venus_features_modules', 'et_pb_on_state' );

if (!get_option( 'venus_header_modules')) add_option( 'venus_header_modules', 'et_pb_on_state' );

if (!get_option( 'venus_person_modules')) add_option( 'venus_person_modules', 'et_pb_on_state' );

if (!get_option( 'venus_pricig_tables_modules')) add_option( 'venus_pricig_tables_modules', 'et_pb_on_state' );

if (!get_option( 'venus_subscribe_modules')) add_option( 'venus_subscribe_modules', 'et_pb_on_state' );

}

register_activation_hook( __FILE__, 'venus_add_options_on_activate' );

if ( get_option( 'venus_assistant_activated' ) == 'Activated') {


// add a link to settings page in plugin list
function add_venus_settings_link( $links ) {
    return array_merge( $links, array( '<a href="' . admin_url( '/options-general.php?page=venus_assistant_dashboard' ) . '">' . __( 'Settings' ) . '</a>') );
  }

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'add_venus_settings_link' ); 


//======================================================================
// LOAD CUSTOM STYLES FOR FRONTEND MODULES
//======================================================================

function venus_assistant_css() {

    if(get_option( 'venus_blog_modules') == 'et_pb_on_state') {
        wp_register_style('venus-blogs-css', plugins_url('css/blog-venus.css',__FILE__ ));
        wp_enqueue_style('venus-blogs-css');
    }

    if(get_option( 'venus_blurbs_modules') == 'et_pb_on_state') {
        wp_register_style('venus-blurb-css', plugins_url('css/blurbs-venus.css',__FILE__ ));
        wp_enqueue_style('venus-blurb-css');
    }

    if(get_option( 'venus_cta_modules') == 'et_pb_on_state') {
        wp_register_style('venus-call-to-action', plugins_url('css/cta-venus.css',__FILE__ ));
        wp_enqueue_style('venus-call-to-action');
    }

    if(get_option( 'venus_form_modules') == 'et_pb_on_state') {
        wp_register_style('venus-contact-page-css', plugins_url('css/contact-venus.css',__FILE__ ));
        wp_enqueue_style('venus-contact-page-css');
    }

    if(get_option( 'venus_faq_modules') == 'et_pb_on_state') {
        wp_register_style('venus-faq-css', plugins_url('css/faq-venus.css',__FILE__ ));
        wp_enqueue_style('venus-faq-css');
    }

    if(get_option( 'venus_features_modules') == 'et_pb_on_state') {
        wp_register_style('venus-features-css', plugins_url('css/features-venus.css',__FILE__ ));
        wp_enqueue_style('venus-features-css');
    }

    if(get_option( 'venus_header_modules') == 'et_pb_on_state') {
        wp_register_style('venus-fancybox-css', plugins_url('js/fancybox/jquery.fancybox.css',__FILE__ ));
        wp_enqueue_style('venus-fancybox-css');

        wp_register_style('venus-header-css', plugins_url('css/header-venus.css',__FILE__ ));
        wp_enqueue_style('venus-header-css');
    }

    if(get_option( 'venus_person_modules') == 'et_pb_on_state') {
        wp_register_style('venus-person-css', plugins_url('css/persons-venus.css',__FILE__ ));
        wp_enqueue_style('venus-person-css');
    }

    if(get_option( 'venus_pricig_tables_modules') == 'et_pb_on_state') {
        wp_register_style('venus-pricing-tables-css', plugins_url('css/pricing-tables-venus.css',__FILE__ ));
        wp_enqueue_style('venus-pricing-tables-css');
    }

    if(get_option( 'venus_subscribe_modules') == 'et_pb_on_state') {
        wp_register_style('venus-subscribe-css', plugins_url('css/subscribe-venus.css',__FILE__ ));
        wp_enqueue_style('venus-subscribe-css');
    }

   
}

add_action( 'wp_footer','venus_assistant_css');
add_action( 'et_fb_enqueue_assets' , 'venus_assistant_css', 1);

//======================================================================
// LOAD CUSTOM SCRIPTS FOR FRONTEND MODULES
//======================================================================

function venus_assistant_js() {
    if(get_option( 'venus_header_modules') == 'et_pb_on_state') {
        wp_enqueue_script('venus-fancybox-js', plugins_url('js/fancybox/jquery.fancybox.js',__FILE__ ));
        wp_enqueue_script('venus-fancybox-pack-js', plugins_url('js/fancybox/jquery.fancybox.pack.js',__FILE__ ));
        wp_register_script( 'venus-header-js', plugins_url('js/venus-header.js',__FILE__ ));
        wp_enqueue_script('venus-header-js');
    }
    if(get_option( 'venus_form_modules') == 'et_pb_on_state') {
        wp_enqueue_script('venus-charming-js', plugins_url('js/charming.min.js',__FILE__ ));
        wp_enqueue_script('venus-nearby-js', plugins_url('js/nearby.js',__FILE__ ));
        wp_enqueue_script('venus-tweenmax-js', plugins_url('js/TweenMax.min.js',__FILE__ ));
        wp_register_script('venus-form-js', plugins_url('js/venus-form.js',__FILE__ ));
        wp_enqueue_script('venus-form-js');
    }

    if(get_option( 'venus_pricig_tables_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-pricing-tables-js', plugins_url('js/venus-pricing-tables.js',__FILE__ ));
        wp_enqueue_script('venus-pricing-tables-js');
    }

    if(get_option( 'venus_features_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-features-js', plugins_url('js/venus-features.js',__FILE__ ));
        wp_enqueue_script('venus-features-js');
    }

    if(get_option( 'venus_blog_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-blog-js', plugins_url('js/venus-blog.js',__FILE__ ));
        wp_enqueue_script('venus-blog-js');
    }

    if(get_option( 'venus_person_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-person-js', plugins_url('js/venus-person.js',__FILE__ ));
        wp_enqueue_script('venus-person-js');
    }

    if(get_option( 'venus_faq_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-faq-js', plugins_url('js/venus-faq.js',__FILE__ ));
        wp_enqueue_script('venus-faq-js');
    }

    if(get_option( 'venus_cta_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-cta-js', plugins_url('js/venus-cta.js',__FILE__ ));
        wp_enqueue_script('venus-cta-js');
    }

    if(get_option( 'venus_subscribe_modules') == 'et_pb_on_state') {
        wp_register_script( 'venus-subscribe-js', plugins_url('js/venus-subscribe.js',__FILE__ ));
        wp_enqueue_script('venus-subscribe-js');
    }
	
}

add_action( 'wp_footer','venus_assistant_js');
add_action( 'et_fb_enqueue_assets' , 'venus_assistant_js');


//======================================================================
// For ajax save
//======================================================================

function venus_update_option(){
      update_option($_POST['venus_option'], esc_attr($_POST['venus_option_val']));
      die();
}

if( is_admin() ) { 
  add_action('wp_ajax_venus_update_option', 'venus_update_option', 10, 2);

}


//======================================================================
// Antispam email shortcode [email]name@website.com[/email]- https://codex.wordpress.org/Function_Reference/antispambot
//======================================================================

if ( !shortcode_exists( 'email' ) ) {

    function wpcodex_hide_email_venus_shortcode($atts, $content = null)
{
    if (!is_email($content)) {
        return;
    }

    return '<a href="mailto:' . antispambot($content) . '">' . antispambot($content) . '</a>';
}

    add_shortcode('email', 'wpcodex_hide_email_venus_shortcode');
}

//======================================================================
// AUTOUPDATE
//======================================================================

require 'plugin-update-checker/plugin-update-checker.php';
$venusUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://s3-eu-west-1.amazonaws.com/ddlicensed/venus/onetime/venuspluginsupdates/venus-plugin-update.json',
	__FILE__,
	'venus_assistant'
);

} // activated check ends


?>